local drawBridge = ...

--------------------------------------------------------------------------

-- Register IDs for all prefab nodes referenced here
drawBridge:registerAssetId("models/drawBridge.fbx/Prefab/drawBridge/CenterPart", "DRAW_BRIDGE_CENTER_PREFAB")
drawBridge:registerAssetId("models/drawBridgeA.fbx/Prefab/drawBridge/CenterPart", "DRAW_BRIDGE_A_CENTER_PREFAB")
drawBridge:registerAssetId("models/drawBridge.fbx/Prefab/drawBridge/RootPart", "DRAW_BRIDGE_CENTER_ROOT_PREFAB")
drawBridge:registerAssetId("models/drawBridge.fbx/Prefab/drawBridge/StartSlopePart", "DRAW_BRIDGE_SLOPE_START_PREFAB")
drawBridge:registerAssetId("models/drawBridge.fbx/Prefab/drawBridge/EndSlopePart", "DRAW_BRIDGE_SLOPE_END_PREFAB")
drawBridge:registerAssetId("models/drawBridge.fbx/Prefab/drawBridge/StartPart", "DRAW_BRIDGE_START_PREFAB")
drawBridge:registerAssetId("models/drawBridge.fbx/Prefab/drawBridge/EndPart", "DRAW_BRIDGE_END_PREFAB")
drawBridge:registerAssetId("models/drawBridge.fbx/Prefab/drawBridge/TilingPart", "DRAW_BRIDGE_TILING_PREFAB")

--------------------------------------------------------------------------

-- Register bridge tiling (the pillar part that extends to the ground)
drawBridge:register({
	DataType = "BUILDING_PART",
	Id = "DRAW_BRIDGE_TILING_PART",
	Mover = { DataType = "BUILDING_PART_MOVER" },
	ConstructorData = {
		DataType = "BUILDING_CONSTRUCTOR_DEFAULT",
		CoreObjectPrefab = "DRAW_BRIDGE_TILING_PREFAB"
	},
	Cost = {
		DataType = "BUILDING_PART_COST",
		RessourcesNeeded = {
			{ Resource = "STONE", Quantity = 1 }
		}
	},
})

-- Register bridge start part
drawBridge:register({
	DataType = "BUILDING_PART",
	Id = "DRAW_BRIDGE_START_PART",
	Mover = { DataType = "BUILDING_PART_MOVER" },
	ConstructorData = {
		DataType = "BUILDING_CONSTRUCTOR_BASEMENT",
		CoreObjectPrefab = "DRAW_BRIDGE_START_PREFAB",
		FillerList = {
			"DRAW_BRIDGE_TILING_PART"
		},
		BasementScale = 2,
	},
	Cost = {
		DataType = "BUILDING_PART_COST",
		RessourcesNeeded = {
			{ Resource = "STONE", Quantity = 2 }
		},
	},
})

-- Register bridge end part
drawBridge:register({
	DataType = "BUILDING_PART",
	Id = "DRAW_BRIDGE_END_PART",
	Mover = { DataType = "BUILDING_PART_MOVER_BRIDGE" },
	ConstructorData = {
		DataType = "BUILDING_CONSTRUCTOR_BASEMENT",
		CoreObjectPrefab = "DRAW_BRIDGE_END_PREFAB",
		FillerList = {
			"DRAW_BRIDGE_TILING_PART"
		},
		BasementScale = 2,
	},
	Cost = {
		DataType = "BUILDING_PART_COST",
		RessourcesNeeded = {
			{ Resource = "STONE", Quantity = 2 }
		},
	},
})

-- Register bridge start slope part
drawBridge:register({
	DataType = "BUILDING_PART",
	Id = "DRAW_BRIDGE_SLOPE_START_PART",
	Mover = { DataType = "BUILDING_PART_MOVER" },
	ConstructorData = {
		DataType = "BUILDING_CONSTRUCTOR_BASEMENT",
		CoreObjectPrefab = "DRAW_BRIDGE_SLOPE_START_PREFAB",
		FillerList = {
			"DRAW_BRIDGE_TILING_PART"
		},
		BasementScale = 2,
	},
	Cost = {
		DataType = "BUILDING_PART_COST",
		RessourcesNeeded = {
			{ Resource = "STONE", Quantity = 1 }
		},
	},
})

-- Register bridge end slope part
drawBridge:register({
	DataType = "BUILDING_PART",
	Id = "DRAW_BRIDGE_SLOPE_END_PART",
	Mover = { DataType = "BUILDING_PART_MOVER" },
	ConstructorData = {
		DataType = "BUILDING_CONSTRUCTOR_BASEMENT",
		CoreObjectPrefab = "DRAW_BRIDGE_SLOPE_END_PREFAB",
		FillerList = {
			"DRAW_BRIDGE_TILING_PART"
		},
		BasementScale = 2,
	},
	Cost = {
		DataType = "BUILDING_PART_COST",
		RessourcesNeeded = {
			{ Resource = "STONE", Quantity = 1 }
		},
	},
})

-- Register bridge center top part
drawBridge:register({
	DataType = "BUILDING_PART",
	Id = "DRAW_BRIDGE_CENTER_TOP_PART",
	Mover = { DataType = "BUILDING_PART_MOVER" },
	ConstructorData = {
		DataType = "BUILDING_CONSTRUCTOR_DEFAULT",
		CoreObjectPrefab = "DRAW_BRIDGE_CENTER_PREFAB"
	},
	Cost = {
		DataType = "BUILDING_PART_COST",
		RessourcesNeeded = {
			{ Resource = "TOOL", Quantity = 2 },
			{ Resource = "PLANK", Quantity = 10 }
		},
	},
})

-- Register bridge center A top part
drawBridge:register({
	DataType = "BUILDING_PART",
	Id = "DRAW_BRIDGE_A_CENTER_TOP_PART",
	Mover = { DataType = "BUILDING_PART_MOVER" },
	ConstructorData = {
		DataType = "BUILDING_CONSTRUCTOR_DEFAULT",
		CoreObjectPrefab = "DRAW_BRIDGE_A_CENTER_PREFAB"
	},
	Cost = {
		DataType = "BUILDING_PART_COST",
		RessourcesNeeded = {
			{ Resource = "TOOL", Quantity = 2 },
			{ Resource = "PLANK", Quantity = 10 }
		},
	},
})

-- Register the center root part (the scalable part that places multiple center top parts)
drawBridge:register({
	DataType = "BUILDING_PART",
	Id = "DRAW_BRIDGE_CENTER_CORE_PART",
	Mover = { DataType = "BUILDING_PART_MOVER" },
	ConstructorData = {
		DataType = "BUILDING_CONSTRUCTOR_SCALER",
		CoreObjectPrefab = "DRAW_BRIDGE_CENTER_ROOT_PREFAB",
		EndPart = "DRAW_BRIDGE_CENTER_TOP_PART",
		FillerList = {
			"DRAW_BRIDGE_TILING_PART"
		},
		BasementScale = 2,
	},
	Cost = {
		DataType = "BUILDING_PART_COST",
		RessourcesNeeded = {
			{ Resource = "PLANK", Quantity = 1 }
		},
	},
})

-- Register the center root A part (the scalable part that places multiple center top parts)
drawBridge:register({
	DataType = "BUILDING_PART",
	Id = "DRAW_BRIDGE_A_CENTER_CORE_PART",
	Mover = { DataType = "BUILDING_PART_MOVER" },
	ConstructorData = {
		DataType = "BUILDING_CONSTRUCTOR_SCALER",
		CoreObjectPrefab = "DRAW_BRIDGE_CENTER_ROOT_PREFAB",
		EndPart = "DRAW_BRIDGE_A_CENTER_TOP_PART",
		FillerList = {
			"DRAW_BRIDGE_TILING_PART"
		},
		BasementScale = 2,
	},
	Cost = {
		DataType = "BUILDING_PART_COST",
		RessourcesNeeded = {
			{ Resource = "PLANK", Quantity = 1 }
		},
	},
})

-- Register the core part (the part with the bridge mover)
drawBridge:register({
	DataType = "BUILDING_PART",
	Id = "DRAW_BRIDGE_CORE_PART",
	Name = "DRAW_BRIDGE_CORE_NAME",
	Mover = { DataType = "BUILDING_PART_MOVER_BRIDGE" },
	ConstructorData = {
		DataType = "BUILDING_CONSTRUCTOR_BRIDGE",
		StartPart = "DRAW_BRIDGE_START_PART",
		EndPart = "DRAW_BRIDGE_END_PART",
		FillerList = {
			"DRAW_BRIDGE_CENTER_CORE_PART"
		},
		SlopeFillerList = {
			"DRAW_BRIDGE_SLOPE_END_PART"
		},
		SlopeStartFillerList = {
			"DRAW_BRIDGE_SLOPE_START_PART"
		},
		MinimumScale = 1,
	},
	AssetBuildingFunction = "DRAW_BRIDGE_FUNCTION_2"
})
drawBridge:register({
		DataType = "BUILDING_FUNCTION_BRIDGE",
                Id = "DRAW_BRIDGE_FUNCTION_2"
})


-- Register the core A part (the part with the bridge mover)
drawBridge:register({
	DataType = "BUILDING_PART",
	Id = "DRAW_BRIDGE_A_CORE_PART",
	Name = "DRAW_BRIDGE_A_CORE_NAME",
	Mover = { DataType = "BUILDING_PART_MOVER_BRIDGE" },
	ConstructorData = {
		DataType = "BUILDING_CONSTRUCTOR_BRIDGE",
		StartPart = "DRAW_BRIDGE_START_PART",
		EndPart = "DRAW_BRIDGE_END_PART",
		FillerList = {
			"DRAW_BRIDGE_A_CENTER_CORE_PART"
		},
		SlopeFillerList = {
			"DRAW_BRIDGE_SLOPE_END_PART"
		},
		SlopeStartFillerList = {
			"DRAW_BRIDGE_SLOPE_START_PART"
		},
		MinimumScale = 1,
	},
	AssetBuildingFunction = "DRAW_BRIDGE_FUNCTION_2"
})
--------------------------------------------------------------------------

-- Override building part components properties (generated by the building asset processor) to add building zones

drawBridge:registerPrefabComponent("models/drawBridge.fbx/Prefab/drawBridge/CenterPart", {
	DataType = "COMP_BUILDING_PART",
	HasBuildingZone = true,
	BuildingZone = { 2, 2 }
})
drawBridge:registerPrefabComponent("models/drawBridgeA.fbx/Prefab/drawBridge/CenterPart", {
	DataType = "COMP_BUILDING_PART",
	HasBuildingZone = true,
	BuildingZone = { 2, 2 }
})
drawBridge:registerPrefabComponent("models/drawBridge.fbx/Prefab/drawBridge/StartPart", {
	DataType = "COMP_BUILDING_PART",
	HasBuildingZone = true,
	BuildingZone = { 2, 2 }
})
drawBridge:registerPrefabComponent("models/drawBridge.fbx/Prefab/drawBridge/EndPart", {
	DataType = "COMP_BUILDING_PART",
	HasBuildingZone = true,
	BuildingZone = { 2, 2 }
})
drawBridge:registerPrefabComponent("models/drawBridge.fbx/Prefab/drawBridge/StartSlopePart", {
	DataType = "COMP_BUILDING_PART",
	HasBuildingZone = true,
	BuildingZone = { 2, 2 }
})
drawBridge:registerPrefabComponent("models/drawBridge.fbx/Prefab/drawBridge/EndSlopePart", {
	DataType = "COMP_BUILDING_PART",
	HasBuildingZone = true,
	BuildingZone = { 2, 2 }
})

--------------------------------------------------------------------------

-- Configure all BRIDGE colliders

drawBridge:configurePrefabFlagList("models/drawBridge.fbx/Prefab/drawBridge/CenterPart", { "BRIDGE" })
drawBridge:configurePrefabFlagList("models/drawBridgeA.fbx/Prefab/drawBridge/CenterPart", { "BRIDGE" })
drawBridge:configurePrefabFlagList("models/drawBridge.fbx/Prefab/drawBridge/StartPart", { "BRIDGE" })
drawBridge:configurePrefabFlagList("models/drawBridge.fbx/Prefab/drawBridge/EndPart", { "BRIDGE" })
drawBridge:configurePrefabFlagList("models/drawBridge.fbx/Prefab/drawBridge/StartSlopePart", { "BRIDGE" })
drawBridge:configurePrefabFlagList("models/drawBridge.fbx/Prefab/drawBridge/EndSlopePart", { "BRIDGE" })
